==> tine20-allinone_2020.03.4.tar.bz2: Tasks/js/Tasks-lang-pl_PL-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Polish (Poland) (http://www.transifex.com/tine20/tine20/language/pl_PL/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: pl_PL\nPlural-Forms: nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "GENDER_Task, GENDER_Tasks"
: [
  ""
 ,""
 ,""
 ,""

]
, "Task, Tasks"
: [
  ""
 ,""
 ,""
 ,""

]
, "Percent"
: ""

, "Completed"
: ""

, "Due"
: ""

, "Class"
: ""

, "Description"
: ""

, "Geo"
: ""

, "Location"
: ""

, "Organizer"
: ""

, "Priority"
: ""

, "Status, Status"
: [
  ""
 ,""
 ,""
 ,""

]
, "Lead"
: ""

, "Telephone"
: ""

, "Email"
: ""

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: ""

, "Summary"
: ""

, "Due date"
: ""

, "Add Responsible ..."
: ""

, "Notes"
: ""

, "Enter description..."
: ""

, "Percentage"
: ""

, "Tasks"
: ""

, "to do list, to do lists"
: [
  ""
 ,""
 ,""
 ,""

]
, "to do lists"
: ""

, "Quick Search"
: ""

, "Due Date"
: ""

, "Responsible"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "New Task"
: ""

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  ""
 ,""
 ,""
 ,""

]
, "Attachments"
: ""

, "Tags"
: ""

, "Lead name"
: ""

, "Add a task..."
: ""

, "All my tasks"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on Tasks startup"
: ""

, "Default Task List"
: ""

, "The default task list to create new tasks in."
: ""

, "Tasks status available"
: ""

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: ""

, "No response"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "Task priorities available"
: ""

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: ""

, "low"
: ""

, "normal"
: ""

, "high"
: ""

, "urgent"
: ""

, "manage shared task lists"
: ""

, "Create new shared tasks lists"
: ""

, "manage shared tasks favorites"
: ""

, "Create or update shared tasks favorites"
: ""

, "%s's personal tasks"
: ""

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: ""

, "My open tasks"
: ""

, "My open tasks this week"
: ""

, "All tasks for me"
: ""

, "All tasks that I am responsible for"
: ""

, "Last modified by me"
: ""

, "All tasks that I have last modified"
: ""

, "Tasks without responsible"
: ""

, "GENDER_Task"
: ""

, "Task"
: ""

, "Status"
: ""

, "to do list"
: ""

, "Do you really want to delete the selected task?"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Tasks/js/Tasks-lang-pl_PL-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Polish (Poland) (http://www.transifex.com/tine20/tine20/language/pl_PL/)\nLanguage: pl_PL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: ""

, "Summary"
: ""

, "Due date"
: ""

, "Priority"
: ""

, "Organizer"
: ""

, "Add Responsible ..."
: ""

, "Notes"
: ""

, "Enter description..."
: ""

, "Percentage"
: ""

, "Status, Status"
: [
  ""
 ,""
 ,""
 ,""

]
, "Completed"
: ""

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  ""
 ,""
 ,""
 ,""

]
, "Attachments"
: ""

, "Tags"
: ""

, "Lead name"
: ""

, "Add a task..."
: ""

, "Due Date"
: ""

, "Percent"
: ""

, "Responsible"
: ""

, "Task, Tasks"
: [
  ""
 ,""
 ,""
 ,""

]
, "Tasks"
: ""

, "to do list, to do lists"
: [
  ""
 ,""
 ,""
 ,""

]
, "to do lists"
: ""

, "Quick Search"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "New Task"
: ""

, "All my tasks"
: ""

, "Default Favorite"
: ""

, "The default favorite which is loaded on Tasks startup"
: ""

, "Default Task List"
: ""

, "The default task list to create new tasks in."
: ""

, "Enable Standard Alarm"
: ""

, "New task get a standard alarm as defined below"
: ""

, "Standard Alarm Time"
: ""

, "Minutes before the task ends"
: ""

, "Tasks status available"
: ""

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: ""

, "No response"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "Task priorities available"
: ""

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: ""

, "low"
: ""

, "normal"
: ""

, "high"
: ""

, "urgent"
: ""

, "%s's personal tasks"
: ""

, "GENDER_Task"
: ""

, "Due"
: ""

, "Class"
: ""

, "Description"
: ""

, "Geo"
: ""

, "Location"
: ""

, "Lead"
: ""

, "Telephone"
: ""

, "Email"
: ""

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: ""

, "My open tasks"
: ""

, "My open tasks this week"
: ""

, "All tasks for me"
: ""

, "All tasks that I am responsible for"
: ""

, "Last modified by me"
: ""

, "All tasks that I have last modified"
: ""

, "Tasks without responsible"
: ""

, "manage shared task lists"
: ""

, "Create new shared tasks lists"
: ""

, "manage shared tasks favorites"
: ""

, "Create or update shared tasks favorites"
: ""

, "Status"
: ""

, "Do you really want to delete the selected task?"
: ""

, "Task"
: ""

, "to do list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
